@@ -110,6 +110,7 @@
 #include "log.h"
 #include "mom_mach.h"
 #include "resmon.h"
+#include "utils.h"
 #include "../rm_dep.h"
 
 /*
@@ -135,7 +136,7 @@
 **  quota  quota information (sizes in KB)
 */
 
-static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 3151 $";
+static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 4925 $";
 
 #ifndef TRUE
 #define FALSE 0
@@ -165,9 +166,9 @@ extern time_t   time_now;
 ** external functions and data
 */
 
-extern struct config  *search A_((struct config *, char *));
+extern struct config  *search(struct config *, char *);
 
-extern struct rm_attribute *momgetattr A_((char *));
+extern struct rm_attribute *momgetattr(char *);
 extern int   rm_errno;
 extern double cputfactor;
 extern double wallfactor;
@@ -180,16 +181,16 @@ extern  int     ignmem;
 /*
 ** local functions and data
 */
-static char *resi  A_((struct rm_attribute *attrib));
-static char *totmem  A_((struct rm_attribute *attrib));
-static char *availmem A_((struct rm_attribute *attrib));
-static char *physmem A_((struct rm_attribute *attrib));
-static char *ncpus  A_((struct rm_attribute *attrib));
-static char *walltime A_((struct rm_attribute *attrib));
-static char *quota  A_((struct rm_attribute *attrib));
+static char *resi(struct rm_attribute *attrib);
+static char *totmem(struct rm_attribute *attrib);
+static char *availmem(struct rm_attribute *attrib);
+static char *physmem(struct rm_attribute *attrib);
+static char *ncpus(struct rm_attribute *attrib);
+static char *walltime(struct rm_attribute *attrib);
+static char *quota(struct rm_attribute *attrib);
 
-extern char *loadave A_((struct rm_attribute *attrib));
-extern char *nullproc A_((struct rm_attribute *attrib));
+extern char *loadave(struct rm_attribute *attrib);
+extern char *nullproc(struct rm_attribute *attrib);
 
 /*
 ** local resource array
@@ -822,7 +823,7 @@ mom_set_limits(
       if (ignvmem == FALSE)
         {
         retval = getsize(pres, &value);
-  
+
         if (retval != PBSE_NONE)
           return (error(pname, retval));
 
@@ -861,7 +862,7 @@ mom_set_limits(
             return (error(pname, retval));
 
           reslim.rlim_cur = reslim.rlim_max = value;
- 
+
           if (setrlimit(RLIMIT_RSS, &reslim) < 0)
             return (error("RLIMIT_RSS", PBSE_SYSTEM));
           }
@@ -2549,7 +2550,7 @@ quota(struct rm_attribute *attrib)
 
   if ((uid = (uid_t)atoi(attrib->a_value)) == 0)
     {
-    if ((pw = getpwnam(attrib->a_value)) == NULL)
+    if ((pw = getpwnam_ext(attrib->a_value)) == NULL)
       {
       sprintf(log_buffer,
               "user not found: %s", attrib->a_value);
