@@ -203,7 +203,7 @@ badplace *is_bad_dest(
  * Returns 0 on success. Non-zero on failure
  */ 
 int initialize_procct(job *pjob)
-  {                \
+  { 
   char id[] = "initialize_procct";
   resource     *pnodesp = NULL;
   resource_def *pnodes_def = NULL;
@@ -368,7 +368,7 @@ int remove_procct(job *pjob)
       pctdef->rs_free(&pctresc->rs_value);
 
   return(PBSE_NONE);
-  }
+  } /* END remove_procct */
 
 
 /*
@@ -456,6 +456,11 @@ int default_router(
 
       case ROUTE_PERM_FAILURE: /* permanent failure */
 
+        rc = remove_procct(jobp);
+        if(rc != PBSE_NONE)
+          {
+          return(rc);
+          }
         add_dest(jobp);
 
         break;
