@@ -832,6 +832,8 @@ int pbsd_init(
 
   server.sv_attr[(int)SRV_ATR_PollJobs].at_val.at_long = PBS_POLLJOBS;
 
+  server.sv_attr[SRV_ATR_MoabArrayCompatible].at_val.at_long = TRUE;
+
   /* 4. force logging of all types */
 
   server.sv_attr[(int)SRV_ATR_log_events].at_val.at_long = PBSEVENT_MASK;
@@ -1051,9 +1053,9 @@ int pbsd_init(
           continue;
 
 
-        pa = array_recov(pdirent->d_name);
+        rc = array_recov(pdirent->d_name, &pa);
 
-        if (pa == NULL)
+        if (rc != PBSE_NONE)
           {
 
           sprintf(log_buffer,
@@ -1063,7 +1065,7 @@ int pbsd_init(
 
           log_err(errno, "pbsd_init", log_buffer);
 
-          continue;
+          return(rc);
 
           }
 
@@ -1282,6 +1284,15 @@ int pbsd_init(
 
   while (pa != NULL)
     {
+    /* see if we need to upgrade the array version. */
+    /* We will upgrade from version 3 or later */
+    if(pa->ai_qs.struct_version == 3)
+      {
+      pa->ai_qs.struct_version = ARRAY_QS_STRUCT_VERSION;
+      pa->ai_qs.num_purged = pa->ai_qs.num_jobs - pa->jobs_recovered;
+      array_save(pa);
+      }
+
     pa->template_job = find_array_template(pa->ai_qs.parent_id);
 
     if (pa->ai_qs.num_cloned != pa->ai_qs.num_jobs)
